/*------------ Telecommunications & Signal Processing Lab --------------
                         McGill University

Routine:
  FNmsg.h

Description:
  Message texts for the TSP FN routines.

Author / revision:
  P. Kabal  Copyright (C) 1997
  $Revision: 1.1 $  $Date: 1997/10/10 18:48:47 $

----------------------------------------------------------------------*/

#ifndef FNmsg_h_
#define FNmsg_h_

/* Error messages */
#define FNM_NonPosValue	"Non-positive input value"

#endif	/* FNmsg_h_ */
