/*------------ Telecommunications & Signal Processing Lab --------------
                         McGill University

Routine:
  UTmsg.h

Description:
  Message texts for the TSP UT routines.

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.3 $  $Date: 1999/06/12 23:46:45 $

----------------------------------------------------------------------*/

#ifndef UTmsg_h_
#define UTmsg_h_

/* Warning messages */
#define UTM_BadOption	"Invalid option"
#define UTM_BadSwap	"Invalid byte swap code"
#define UTM_ExpectValue	"Value expected for option"

#endif	/* UTmsg_h_ */
