/*------------ Telecommunications & Signal Processing Lab --------------
                         McGill University

Routine:
  VRmsg.h

Description:
  Message texts for the TSP VR routines.

Author / revision:
  P. Kabal  Copyright (C) 1997
  $Revision: 1.2 $  $Date: 1997/10/11 02:21:30 $

----------------------------------------------------------------------*/

#ifndef VRmsg_h_
#define VRmsg_h_

/* Error Messages */
#define VRM_BadSize	"Invalid data element size"
#define VRM_NegAmpl	"Negative input amplitude"
#define VRM_NegVal	"Negative input value(s)"
#define VRM_BadN	"Invalid number of elements"

#endif	/* VRmsg_h_ */
