/*------------ Telecommunications & Signal Processing Lab --------------
                         McGill University

Routine:
  MSmsg.h

Description:
  Message texts for the TSP MS routines.

Author / revision:
  P. Kabal  Copyright (C) 1997
  $Revision: 1.2 $  $Date: 1997/10/11 02:27:30 $

----------------------------------------------------------------------*/

#ifndef MSmsg_h_
#define MSmsg_h_

/* Error messages */
#define MSM_BadAbsVal	"Abscissa value out of range"
#define MSM_NonIncrAbs	"Abscissa values not in increasing order"

#endif	/* MSmsg_h_ */
