/*------------ Telecommunications & Signal Processing Lab --------------
                         McGill University

Routine:
  FImsg.h

Description:
  Message texts for the TSP FI routines.

Author / revision:
  P. Kabal  Copyright (C) 1997
  $Revision: 1.4 $  $Date: 1997/10/16 00:06:45 $

----------------------------------------------------------------------*/

#ifndef FImsg_h_
#define FImsg_h_

/* I/O errors */
#define FIM_OpenRErr	"Error opening input file"

/* Error messages */
#define FIM_BadWAdv	"Invalid window advance value"
#define FIM_BadWPar	"Invalid window parameter(s)"
#define FIM_IIRNCoefErr	"IIR filter: No. coef. must be a multiple of 5"
#define FIM_NonCausal	"Non-causal filter, first coefficient is zero"

/* Filter file information printout */
#define FIMF_FiltFile	" Filter file: %s\n"
#define FIMF_FiltType	"   %s  %s\n"
#define FIMF_NumCoef	"   Number of coefficients: %d\n"
#define FIMF_NumIIR1	"   Number of coefficients: %d  (1 section)\n"
#define FIMF_NumIIRN	"   Number of coefficients: %d  (%d sections)\n"

#endif	/* FImsg_h_ */
